/*
  Copyright 2013 Jerome Leleu

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package org.pac4j.j2e.filter;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.pac4j.core.util.CommonHelper;
import org.pac4j.j2e.configuration.ClientsConfiguration;

/**
 * An abstract class which handles the configuration of the clients.
 * 
 * @author Jerome Leleu
 * @since 1.0.0
 */
public abstract class ClientsConfigFilter implements Filter {
    
    public void init(final FilterConfig filterConfig) throws ServletException {
        final String clientsFactory = filterConfig.getInitParameter("clientsFactory");
        CommonHelper.assertNotBlank("clientsFactory", clientsFactory);
        ClientsConfiguration.build(clientsFactory);
        CommonHelper.assertNotNull("clients", ClientsConfiguration.getClients());
    }
    
    public void doFilter(final ServletRequest request, final ServletResponse response, final FilterChain chain)
        throws IOException, ServletException {
        final HttpServletRequest req = (HttpServletRequest) request;
        final HttpServletResponse resp = (HttpServletResponse) response;
        final HttpSession session = req.getSession(true);
        
        internalFilter(req, resp, session, chain);
    }
    
    protected abstract void internalFilter(final HttpServletRequest request, final HttpServletResponse response,
                                           final HttpSession session, final FilterChain chain) throws IOException,
        ServletException;
    
    public void destroy() {
    }
}
